@@ -1,9 +1,9 @@
 // ------------------------------------------------------------------------
 // ecasound.cpp: Console mode user interface to ecasound.
-// Copyright (C) 2002-2006 Kai Vehmanen
+// Copyright (C) 2002-2007 Kai Vehmanen
 //
 // Attributes:
-//     eca-style-version: 3
+//     eca-style-version: 3 (see Ecasound Programmer's Guide)
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <config.h>
 #endif
 
+#include <cstdlib>
 #include <iostream>
 #include <string>
 #include <vector>
@@ -79,7 +80,7 @@ static struct ecasound_state ecasound_state_global =
     0,        /* pthread_mutex_t - lock */
     0,        /* sig_wait_t - exit_request */
     0,        /* sigset_t */
-    0,        /* int - return value */
+    ECASOUND_RETVAL_SUCCESS, /* int - return value */
     2868,     /* int - default daemon mode TCP-port */
     false,    /* daemon mode */
     false,    /* keep_running mode */
@@ -89,6 +90,7 @@ static struct ecasound_state ecasound_state_global =
   };
 
 static sig_atomic_t ecasound_cleanup_done = 0;
+static sig_atomic_t ecasound_normal_exit = 0;
 
 /**
  * Namespace imports
@@ -112,9 +114,9 @@ int main(int argc, char *argv[])
   delete cline; cline = 0;
 
   /* 3. create console interface */
-  if (state->retval == 0) {
+  if (state->retval == ECASOUND_RETVAL_SUCCESS) {
 
-#if defined(ECA_USE_NCURSES_H) || defined(ECA_USE_NCURSES_NCURSES_H) || defined(ECA_USE_CURSES_H)
+#if defined(ECA_PLATFORM_CURSES) 
     if (state->quiet_mode != true &&
 	state->cerr_output_only_mode != true) {
       state->console = new ECA_CURSES();
@@ -145,14 +147,14 @@ int main(int argc, char *argv[])
     delete clineout; clineout = 0;
 
     /* 7. start ecasound daemon */
-    if (state->retval == 0) {
+    if (state->retval == ECASOUND_RETVAL_SUCCESS) {
       if (state->daemon_mode == true) {
 	ecasound_launch_daemon(state);
       }
     }
 
     /* 8. start processing */
-    if (state->retval == 0) {
+    if (state->retval == ECASOUND_RETVAL_SUCCESS) {
       ecasound_main_loop(state);
     }
   }
@@ -173,6 +175,7 @@ int main(int argc, char *argv[])
    *       dynamic libraries and libecasound cleanup routines
    *       when run from atexit handler
    */
+  ecasound_normal_exit = 1;
   ecasound_atexit_cleanup();
 
   // cerr << endl << "ecasound: main() exiting..." << endl << endl;
@@ -201,9 +204,17 @@ void ecasound_atexit_cleanup(void)
       }
     }
 
+    if (ecasound_normal_exit == 1 ||
+	state->interactive_mode == true) {
+      /* note: do not call destructors in the case ECA_CONTROL::run()
+       * could still be running (in non-interactive mode, atexit
+       * called due to a signal)	
+       */
+      if (state->control != 0) { delete state->control; state->control = 0; }
+      if (state->session != 0) { delete state->session; state->session = 0; }
+    }
+
     if (state->eciserver != 0) { delete state->eciserver; state->eciserver = 0; }
-    if (state->control != 0) { delete state->control; state->control = 0; }
-    if (state->session != 0) { delete state->session; state->session = 0; }
     if (state->console != 0) { delete state->console; state->console = 0; }
     if (state->daemon_thread != 0) { delete state->daemon_thread; state->daemon_thread = 0; }
     if (state->lock != 0) { delete state->lock; state->lock = 0; }
@@ -231,7 +242,7 @@ void ecasound_create_eca_objects(struct ecasound_state* state,
   }
   catch(ECA_ERROR& e) {
     state->console->print("---\necasound: ERROR: [" + e.error_section() + "] : \"" + e.error_message() + "\"\n");
-    state->retval = -1;
+    state->retval = ECASOUND_RETVAL_INIT_FAILURE;
   }
 }
 
@@ -317,10 +328,15 @@ void ecasound_main_loop(struct ecasound_state* state)
     }
 
     if (ctrl->is_connected() == true) {
-      ctrl->run(!state->keep_running_mode);
+      int res = ctrl->run(!state->keep_running_mode);
+      if (res < 0) {
+	state->retval = ECASOUND_RETVAL_RUNTIME_ERROR;
+	cerr << "ecasound: Warning! Errors detected during processing." << endl;
+      }
     }
     else {
       ctrl->print_last_value();
+      state->retval = ECASOUND_RETVAL_START_ERROR;
     }
 
     if (state->daemon_mode == true) {
@@ -340,7 +356,7 @@ void ecasound_parse_command_line(struct ecasound_state* state,
 {
   if (cline.size() < 2) {
     ecasound_print_usage();
-    state->retval = -1;
+    state->retval = ECASOUND_RETVAL_INIT_FAILURE;
   }
   else {
    cline.begin();
@@ -387,7 +403,7 @@ void ecasound_parse_command_line(struct ecasound_state* state,
       else if (cline.current() == "-h" ||
 	       cline.current() == "--help") {
 	ecasound_print_usage();
-	state->retval = -1;
+	state->retval = ECASOUND_RETVAL_INIT_FAILURE;
 	break;
       }
 
@@ -398,7 +414,7 @@ void ecasound_parse_command_line(struct ecasound_state* state,
 
       else if (cline.current() == "--version") {
 	ecasound_print_version_banner();
-	state->retval = -1;
+	state->retval = ECASOUND_RETVAL_INIT_FAILURE;
 	break;
       }
       
@@ -420,7 +436,7 @@ void ecasound_print_usage(void)
 void ecasound_print_version_banner(void)
 {
   cout << "ecasound v" << ecasound_library_version << endl;
-  cout << "Copyright (C) 1997-2006 Kai Vehmanen and others." << endl;
+  cout << "Copyright (C) 1997-2007 Kai Vehmanen and others." << endl;
   cout << "Ecasound comes with ABSOLUTELY NO WARRANTY." << endl;
   cout << "You may redistribute copies of ecasound under the terms of the GNU" << endl;
   cout << "General Public License. For more information about these matters, see" << endl; 
@@ -525,6 +541,11 @@ void* ecasound_watchdog_thread(void* arg)
 
   state->exit_request = 1;
   
+  DBC_CHECK(state->retval == ECASOUND_RETVAL_SUCCESS ||
+	    state->retval == ECASOUND_RETVAL_INIT_FAILURE ||
+	    state->retval == ECASOUND_RETVAL_START_ERROR ||
+	    state->retval == ECASOUND_RETVAL_RUNTIME_ERROR);
+  
   exit(state->retval);
 
   /* to keep the compilers happy; never actually executed */
