@@ -13,7 +13,12 @@
 
 #include <iostream>
 #include <unistd.h>
-#include <ecasound/eca-control-interface.h>
+#include <eca-control-interface.h>
+
+/* compile with: 
+ *
+ * c++ -o ecidoc_example ecidoc_example.cpp `libecasoundc-config --cflags --libs`
+ */
 
 int main(int argc, char *argv[])
 {
@@ -22,8 +27,8 @@ int main(int argc, char *argv[])
   ECA_CONTROL_INTERFACE e;
   e.command("cs-add play_chainsetup");
   e.command("c-add 1st_chain");
-  e.command("-i:some_file.wav");
-  e.command("-o:/dev/dsp");
+  e.command("ai-add foo.wav");
+  e.command("ao-add /dev/dsp");
   e.command("cop-add -efl:100");
   e.command("cop-select 1");
   e.command("copp-select 1");
@@ -44,7 +49,7 @@ int main(int argc, char *argv[])
   e.command("stop");
   e.command("cs-disconnect");
   e.command("cop-status");
-  cerr << "Chain operator status: " << e.last_string() << endl;
+  std::cerr << "Chain operator status: " << e.last_string() << std::endl;
 
   return(0);
 }
