@@ -30,6 +30,10 @@
 #include <string>
 #include <vector>
 
+#if HAVE_LOCALE_H
+#include <locale.h> /* setlocale */
+#endif
+
 #include <time.h> /* nanosleep() */
 #include <sys/time.h> /* gettimeofday() */
 #include <unistd.h> /* usleep() */
@@ -153,6 +157,7 @@ vector<string> kvu_string_to_tokens(const string& s)
  *
  * Unlike string_to_tokens(), quotes can be used to mark 
  * groups of words as tokens (e.g. "this is one token").
+ * The tokens are not removed from the string. 
  * Single-quotes (') are not supported.
  *
  * It's also possible to add individual whitespace
@@ -169,18 +174,23 @@ vector<string> kvu_string_to_tokens_quoted(const string& s)
   for(string::const_iterator p = s.begin(); p != s.end(); p++) {
     if (*p == '\"') {
       quoteflag = !quoteflag;
+      stmp += *p;
     }
     else if (*p == '\\') {
       p++;
+      if (p == s.end()) break;
       stmp += *p;
     }
     else if (isspace(*p) == 0 || quoteflag == true) {
       stmp += *p;
     }
     else {
-      if (stmp == "") continue;
+      /* note: token ready, add to vector if length is non-zero */
+      if (stmp.size() == 0) continue;
+
       vec.push_back(stmp);
       stmp = "";
+      DBC_CHECK(stmp.size() == 0);
     }
   }
   if (stmp.size() > 0)
@@ -433,18 +443,32 @@ void kvu_to_lowercase(string& a)
  * position.
  * 
  * All backslash escaped instances of 'value' ("\<value>")
- * are ignored in the search. Note that general backlash 
- * escaping is not supported, i.e. "\<character>" is not
- * interpreted as "<character>".
+ * are ignored in the search. Also instance of 'value' within 
+ * a pair of double quotes are ignored.
+ *
+ * Note that general backlash escaping is not supported, i.e. 
+ * "\<character>" is not interpreted as "<character>".
  *
  * @return position of next 'value' or arg.end() if not found
  */
 static string::const_iterator kvu_priv_find_next_instance(const string& arg, const string::const_iterator& start, const string::value_type value)
 {
-  string::const_iterator curpos = start, ret = arg.end();
+  string::const_iterator curpos = start, ret = arg.end(), nextquote = arg.end();
 
   while(curpos != arg.end()) {
     ret = find(curpos, arg.end(), value);
+
+    nextquote = find(curpos, arg.end(), '"'); 
+    if (nextquote < ret) {
+
+      /* step: ignore quoted part of the input string */
+      nextquote = find(nextquote + 1, arg.end(), '"');
+      if (nextquote != arg.end()) {
+	curpos = nextquote + 1;
+	ret = find(curpos, arg.end(), value);
+      }
+    }
+
     if (ret != arg.end() && ret != arg.begin()) {
       string::const_iterator prev = ret - 1;
       if ((*prev) == '\\') {
@@ -452,6 +476,7 @@ static string::const_iterator kvu_priv_find_next_instance(const string& arg, con
 	continue;
       }
     }
+
     break;
   }
 
@@ -491,6 +516,21 @@ static void kvu_priv_strip_escapes(string* const input, const string& escaped_ch
   }
 }
 
+/**
+ * Strips the outer quotes of type 'quote_char' from the string.
+ * The string is only modified if the the string starts with,
+ * and ends to, a character matching 'quote_char'.
+ *
+ * @pre escaped_char.size() == 1
+ */
+void kvu_string_strip_outer_quotes(string* input, const std::string::value_type quote_char)
+{
+  if (input->size() >= 2 &&
+      *input->begin() == quote_char &&
+      *(input->end() - 1) == quote_char)
+    *input = std::string(input->begin() + 1, input->end() - 1);
+}
+
 /** 
  * Returns number of arguments in formatted string 'arg'.
  */
@@ -502,6 +542,9 @@ int kvu_get_number_of_arguments(const string& arg)
 /**
  * Returns a vector of all arguments from a formatted string
  *
+ * Note: forces locale to "POSIX" as decimal separate must be
+ *       be period (.) in order to argument separation to work
+ *
  * @param argu a formatted string: "something:arg1,arg2,...,argn"
  */
 vector<string> kvu_get_arguments(const string& argu)
@@ -518,6 +561,10 @@ vector<string> kvu_get_arguments(const string& argu)
   else 
     ++b;
 
+#if HAVE_SETLOCALE
+  setlocale (LC_NUMERIC, "POSIX");
+#endif
+
   for(; b != argu.end(); b++) {
     e = kvu_priv_find_next_instance(argu, b, ',');
     string target = string(b, e);
@@ -525,6 +572,7 @@ vector<string> kvu_get_arguments(const string& argu)
       // strip backslash-commas (and leave the commas in place)      
       kvu_priv_strip_escapes(&target, ",");
       kvu_priv_strip_escapes(&target, ":");
+      kvu_string_strip_outer_quotes(&target, '"');
       resvec.push_back(target);
     }
     if (e == argu.end()) break;
