@@ -1,5 +1,7 @@
-#ifndef _AUDIOIO_LOOP_DEVICE_H
-#define _AUDIOIO_LOOP_DEVICE_H
+#ifndef INCLUDED_AUDIOIO_LOOP_DEVICE_H
+#define INCLUDED_AUDIOIO_LOOP_DEVICE_H
+
+#include <iostream>
 
 #include "audioio.h"
 #include "samplebuffer.h"
@@ -9,36 +11,30 @@
  */
 class LOOP_DEVICE : public AUDIO_IO {
 
-  int id_rep;
-  int writes_rep;
-  int registered_inputs_rep;
-  int registered_outputs_rep;
-
-  bool writes_finished_rep, finished_rep;
-  bool filled_rep;
-    
-  SAMPLE_BUFFER sbuf;
-
  public:
 
-  virtual string name(void) const { return("Internal loop device"); }
-  virtual string description(void) const { return("Loop device that routes data from output to input."); }
+  LOOP_DEVICE(int id);
+  LOOP_DEVICE(void) { }
+  virtual ~LOOP_DEVICE(void);
 
-  virtual void buffersize(long int samples, long int sample_rate) { };
+  virtual LOOP_DEVICE* clone(void) const;
+  virtual LOOP_DEVICE* new_expr(void) const { return new LOOP_DEVICE(); }
+
+  virtual std::string name(void) const { return("Internal loop device"); }
+  virtual std::string description(void) const { return("Loop device that routes data from output to input."); }
+
+  virtual void set_buffersize(long int samples) { };
   virtual long int buffersize(void) const { return(0); };
 
-  virtual void open(void) throw (AUDIO_IO::SETUP_ERROR &) { }
-  virtual void close(void) { }
-
   virtual void read_buffer(SAMPLE_BUFFER* sbuf);
   virtual void write_buffer(SAMPLE_BUFFER* sbuf);
 
   virtual bool finished(void) const;
-  virtual void seek_position(void) { } 
+  virtual void seek_position(void);
 
-  virtual string parameter_names(void) const { return("label,id_number"); }
-  virtual void set_parameter(int param, string value);
-  virtual string get_parameter(int param) const;
+  virtual std::string parameter_names(void) const { return("label,id_number"); }
+  virtual void set_parameter(int param, std::string value);
+  virtual std::string get_parameter(int param) const;
 
   /**
    * Register a new input client
@@ -52,11 +48,18 @@ class LOOP_DEVICE : public AUDIO_IO {
 
   int id(void) const { return(id_rep); }
 
-  LOOP_DEVICE(int id);
-  LOOP_DEVICE(void) { }
-  ~LOOP_DEVICE(void) { }
-  LOOP_DEVICE* clone(void) { return new LOOP_DEVICE(*this); }
-  LOOP_DEVICE* new_expr(void) { return new LOOP_DEVICE(); }
+private:
+
+  int id_rep;
+  int writes_rep;
+  int registered_inputs_rep;
+  int registered_outputs_rep;
+  int empty_rounds_rep;
+
+  bool finished_rep;
+  bool filled_rep;
+    
+  SAMPLE_BUFFER sbuf;
 };
 
 #endif
