@@ -3,10 +3,10 @@
 
 #include <string>
 #include <iostream>
-#include <stdint.h>
-#include <sys/types.h>
 
-#include "audioio-types.h"
+#include <kvu_inttypes.h>
+
+#include "audioio-buffered.h"
 #include "samplebuffer.h"
 #include "eca-fileio.h"
 
@@ -18,7 +18,7 @@
  * Format 1 sample data: Pulse Code Modulation (PCM) Format
  *
  * Format 3 sample data: IEEE754 floats, range [-1, +1)
-
+ *
  * - multiple channels are interleaved
  *
  * - 8, 16, 24 and 32 bit data supported
@@ -58,7 +58,7 @@ class WAVEFILE : public AUDIO_IO_BUFFERED {
   RF riff_format_rep;
 
   long int data_start_position_rep;
-  string mmaptoggle_rep;
+  std::string mmaptoggle_rep;
 
   /**
    * Do a info query prior to actually opening the device.
@@ -97,9 +97,15 @@ class WAVEFILE : public AUDIO_IO_BUFFERED {
     
  public:
 
-  virtual string name(void) const { return("RIFF wave file"); }
+  WAVEFILE (const std::string& name = "");
+  virtual ~WAVEFILE(void);
+
+  virtual WAVEFILE* clone(void) const;
+  virtual WAVEFILE* new_expr(void) const { return new WAVEFILE(); }
+
+  virtual std::string name(void) const { return("RIFF wave file"); }
   virtual bool locked_audio_format(void) const { return(true); }
-  virtual string parameter_names(void) const { return("label,toggle_mmap"); }
+  virtual std::string parameter_names(void) const { return("filename,toggle_mmap"); }
 
   virtual void open(void) throw(AUDIO_IO::SETUP_ERROR &);
   virtual void close(void);
@@ -110,30 +116,25 @@ class WAVEFILE : public AUDIO_IO_BUFFERED {
   virtual bool finished(void) const;
   virtual void seek_position(void);
 
-  virtual void set_parameter(int param, string value);
-  virtual string get_parameter(int param) const;
-
-  WAVEFILE (const string& name = "");
-  ~WAVEFILE(void);
-  WAVEFILE* clone(void) { cerr << "Not implemented!" << endl; return this; }
-  WAVEFILE* new_expr(void) { return new WAVEFILE(); }
+  virtual void set_parameter(int param, std::string value);
+  virtual std::string get_parameter(int param) const;
 
  private:
 
-  WAVEFILE(const WAVEFILE& x) { cerr << "WAVE construct"; }
+  WAVEFILE(const WAVEFILE& x) { std::cerr << "WAVE construct"; }
   WAVEFILE& operator=(const WAVEFILE& x) {  return(*this); }
 
   void update(void);        
   void set_length_in_bytes(void);
   void read_riff_header (void) throw(AUDIO_IO::SETUP_ERROR&);
-  bool next_riff_block(RB *t, unsigned long int *offtmp);
+  bool next_riff_block(RB *t, off_t *offtmp);
   void read_riff_fmt(void) throw(AUDIO_IO::SETUP_ERROR&);
   void write_riff_header (void) throw(AUDIO_IO::SETUP_ERROR&);
   void write_riff_fmt(void);
   void write_riff_datablock(void);
   void update_riff_datablock(void);
   void find_riff_datablock (void) throw(AUDIO_IO::SETUP_ERROR&);
-  signed long int find_block(const char* fblock);
+  bool find_block(const char* fblock);
 };
 
 #endif
