@@ -1,9 +1,8 @@
 #ifndef INCLUDED_DYNAMIC_PARAMETERS_H
 #define INCLUDED_DYNAMIC_PARAMETERS_H
 
-#include <vector>
 #include <string>
-#include <kvutils/kvutils.h>
+#include <kvu_utils.h>
 
 /**
  * Virtual template class that provides a system for dynamically 
@@ -17,25 +16,29 @@ class DYNAMIC_PARAMETERS {
 
  public:
 
-  typedef T parameter_type;
+  typedef T parameter_t;
+
+ public:
+
+  virtual ~DYNAMIC_PARAMETERS (void) { }
 
   /**
    * Gets the total number of of parameters.
    */
-  int number_of_params(void) const { return(string_to_vector(parameter_names(), ',').size()); }
+  int number_of_params(void) const { return kvu_get_number_of_arguments(parameter_names()); }
 
   /**
    * Gets name of parameter with index 'id'.
    * @param id parameter id number
    * 
    */
-  string get_parameter_name(int id) const { return(get_argument_number(id, parameter_names())); }
+  std::string get_parameter_name(int id) const { return(kvu_get_argument_number(id, parameter_names())); }
 
   /**
    * A comma-separated list of parameters names. Derived classes 
    * must implement this.
    */
-  virtual string parameter_names(void) const = 0;
+  virtual std::string parameter_names(void) const = 0;
 
   /**
    * Sets the parameter value. Implementations should be able to
@@ -55,8 +58,6 @@ class DYNAMIC_PARAMETERS {
    * @param param parameter id, require: param > 0
    */
   virtual T get_parameter(int param) const = 0;
-
-  virtual ~DYNAMIC_PARAMETERS (void) { }
 };
 
 #endif
