@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // eca-chain.cpp: Class representing an abstract audio signal chain.
-// Copyright (C) 1999-2006 Kai Vehmanen
+// Copyright (C) 1999-2007 Kai Vehmanen
 // Copyright (C) 2005 Stuart Allie
 //
 // Attributes:
@@ -64,7 +64,7 @@ CHAIN::CHAIN (void)
 {
   ECA_LOG_MSG(ECA_LOGGER::system_objects, "constructor: CHAIN");
   muted_rep = false;
-  sfx_rep = false;
+  sfx_rep = true;
   initialized_rep = false;
   input_id_rep = output_id_rep = -1;
 
@@ -147,7 +147,6 @@ void CHAIN::disconnect_buffer(void) { audioslot_repp = 0; initialized_rep = fals
  *
  * ensure:
  *  selected_chain_operator() == number_of_chain_operators()
- *  is_processing()
  *  is_initialized() != true
  */
 void CHAIN::add_chain_operator(CHAIN_OPERATOR* chainop)
@@ -164,12 +163,10 @@ void CHAIN::add_chain_operator(CHAIN_OPERATOR* chainop)
   chainops_rep.push_back(chainop);
   selected_chainop_repp = chainop;
   selected_chainop_number_rep = chainops_rep.size();
-  sfx_rep = true;
   initialized_rep = false;
 
   // --------
   DBC_ENSURE(selected_chain_operator() == number_of_chain_operators());
-  DBC_ENSURE(is_processing() == true);
   DBC_ENSURE(is_initialized() != true);
   // --------
 }
@@ -182,8 +179,6 @@ void CHAIN::add_chain_operator(CHAIN_OPERATOR* chainop)
  *  selected_chain_operator() > 0
  *
  * ensure:
- *  (chainsops.size() == 0 && is_processing()) ||
- *  (chainsops.size() != 0 && !is_processing()) &&
  *  is_initialized() != true
  */
 void CHAIN::remove_chain_operator(void)
@@ -194,33 +189,38 @@ void CHAIN::remove_chain_operator(void)
   // --------
 
   int n = 0;
-  for(std::vector<CHAIN_OPERATOR*>::iterator p = chainops_rep.begin(); p !=
-	chainops_rep.end(); p++) {
+  for(std::vector<CHAIN_OPERATOR*>::iterator p = chainops_rep.begin(); 
+      p != chainops_rep.end(); 
+      p++) {
     ++n;
     if (n == selected_chain_operator()) {
-      for(std::vector<GENERIC_CONTROLLER*>::iterator q = gcontrollers_rep.begin(); q !=
-	    gcontrollers_rep.end(); q++) {
+      for(std::vector<GENERIC_CONTROLLER*>::iterator q = gcontrollers_rep.begin(); 
+	  q != gcontrollers_rep.end();) {
 	if ((*p) == (*q)->target_pointer()) {
+	  /* step: if the deleted controlled is selected, unselect it */ 
+	  if (selected_controller_repp == *q)
+	    selected_controller_repp = 0;
+
+	  /* step: remove the related controller */
 	  delete *q;
 	  gcontrollers_rep.erase(q);
-	  select_controller(0);
-	  break;
+
+	  /* step: in case there are multiple controllers per chainop */
+	  q = gcontrollers_rep.begin();
 	}
+	else
+	  ++q;
       }
+      /* step: unselect, delete and remove from the list */
       delete *p;
       chainops_rep.erase(p);
-      select_chain_operator(0);
+      selected_chainop_repp = 0;
       break;
     }
   }
-  if (chainops_rep.size() == 0) {
-    sfx_rep = false;
-  }
   initialized_rep = false; 
 
   // --------
-  DBC_ENSURE(chainops_rep.size() == 0 && !is_processing() ||
-	     chainops_rep.size() != 0 && is_processing());
   DBC_ENSURE(is_initialized() != true);
   // --------
 }
@@ -421,7 +421,6 @@ void CHAIN::clear(void)
   gcontrollers_rep.resize(0);
 
   initialized_rep = false;
-  sfx_rep = false;
 }
 
 /**
@@ -449,11 +448,12 @@ void CHAIN::select_chain_operator(int index)
 }
 
 /**
- * Selects a chain operator parameter
+ * Selects a chain operator parameter. Index of zero clears out 
+ * current selection.
  *
  * require:
- *  index > 0
- *  selected_chain_operator() != 0
+ *  index >= 0
+ *  selected_chain_operator() != 0 || index == 0
  *  index <= selected_chain_operator()->number_of_params()
  *
  * ensure:
@@ -466,10 +466,11 @@ void CHAIN::select_chain_operator_parameter(int index)
 
 
 /**
- * Selects a controller.
+ * Selects a controller. Index of zero clears out 
+ * current selection.
  *
  * require:
- *  index > 0
+ *  index >= 0
  *
  * ensure:
  *  index == selected_controller() ||
@@ -488,11 +489,12 @@ void CHAIN::select_controller(int index)
 }
 
 /**
- * Selects a controller parameter
+ * Selects a controller parameter. Index of zero clears out 
+ * current selection.
  *
  * require:
- *  index > 0
- *  selected_controller() != 0
+ *  index >= 0
+ *  selected_controller() != 0 || index == 0
  *  index <= selected_controller()->number_of_params()
  *
  * ensure:
@@ -665,13 +667,14 @@ void CHAIN::process(void)
   // --------
 
   controller_update();
-  if (muted_rep == false) {
+  /* note: if muted, don't bother running the chainops */
+  if (muted_rep != true) {
+    /* note: check if in bypass mode */
     if (sfx_rep == true) {
       for(int p = 0; p != static_cast<int>(chainops_rep.size()); p++) {
 	audioslot_repp->number_of_channels(chainops_rep[p]->output_channels(audioslot_repp->number_of_channels()));
 	chainops_rep[p]->process();
       }
-      //    audioslot_repp.limit_values();
     }
   }
   else {
