@@ -85,16 +85,21 @@ ECA_CONTROL::ECA_CONTROL (ECA_SESSION* psession)
     wellformed_mode_rep(false),
     ctrl_dump_rep(this)
 {
+  ECA_LOG_MSG(ECA_LOGGER::system_objects, "ECA_CONTROL constructor");
 }
 
 ECA_CONTROL::~ECA_CONTROL(void)
 {
+  ECA_LOG_MSG(ECA_LOGGER::system_objects, "ECA_CONTROL destructor");
 }
 
 void ECA_CONTROL::command(const string& cmd)
 {
   clear_last_values();
   clear_action_arguments();
+
+  ECA_LOG_MSG(ECA_LOGGER::user_objects, "command: " + cmd);
+
   vector<string> cmds = kvu_string_to_tokens_quoted(cmd);
   vector<string>::iterator p = cmds.begin();
   if (p != cmds.end()) {
@@ -313,12 +318,24 @@ void ECA_CONTROL::action(int action_id)
   case ec_exit: { quit(); break; }
   case ec_start: 
     { 
-      if (is_running() != true) start();
+      if (is_running() != true) {
+	int result = start();
+	if (result < 0) {
+	  set_last_error("Error, unable to start processing");
+	}
+      }
       // ECA_LOG_MSG(ECA_LOGGER::info, "Can't perform requested action; no chainsetup connected.");
       break; 
     }
   case ec_stop: { if (is_running() == true) stop(); break; }
-  case ec_run: { run(); break; }
+  case ec_run: 
+    { 
+      int result = run(); 
+      if (result < 0) {
+	set_last_error("Errors during processing");
+      }
+      break; 
+    }
   case ec_debug:
     {
       int level = atoi(action_args_rep.c_str());
@@ -326,6 +343,11 @@ void ECA_CONTROL::action(int action_id)
       set_last_string("Debug level set to " + kvu_numtostr(level) + ".");
       break;
     }
+  case ec_resource_file:
+    {
+      session_repp->interpret_general_option(string("-R:") + action_args_rep);
+      break;
+    }
 
     // ---
     // Chainsetups
@@ -455,7 +477,7 @@ void ECA_CONTROL::action(int action_id)
     // Audio input objects
     // ---
   case ec_ai_add: { add_audio_input(action_args_rep); break; }
-  case ec_ai_describe: { set_last_string(ECA_OBJECT_FACTORY::audio_object_to_eos(selected_audio_input_repp)); break; }
+  case ec_ai_describe: { set_last_string(ECA_OBJECT_FACTORY::audio_object_to_eos(selected_audio_input_repp, "i")); break; }
   case ec_ai_remove: { remove_audio_input(); break; }
   case ec_ai_list: { set_last_string_list(audio_input_names()); break; }
   case ec_ai_select: { select_audio_input(action_args_rep); break; }
@@ -500,7 +522,7 @@ void ECA_CONTROL::action(int action_id)
     // ---
   case ec_ao_add: { if (action_args_rep.size() == 0) add_default_output(); else add_audio_output(action_args_rep); break; }
   case ec_ao_add_default: { add_default_output(); break; }
-  case ec_ao_describe: { set_last_string(ECA_OBJECT_FACTORY::audio_object_to_eos(selected_audio_output_repp)); break; }
+  case ec_ao_describe: { set_last_string(ECA_OBJECT_FACTORY::audio_object_to_eos(selected_audio_output_repp, "o")); break; }
   case ec_ao_remove: { remove_audio_output(); break; }
   case ec_ao_list: { set_last_string_list(audio_output_names()); break; }
   case ec_ao_select: { select_audio_output(action_args_rep); break; }
