@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // eca-fileio-mmap.cpp: mmap based file-I/O and buffering routines.
-// Copyright (C) 1999-2000 Kai Vehmanen (kaiv@wakkanet.fi)
+// Copyright (C) 1999-2002 Kai Vehmanen
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -17,8 +17,12 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 // ------------------------------------------------------------------------
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <cstdio>
-#include <cstring>
+#include <cstring> /* memcpy */
 #include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -32,9 +36,10 @@
 ECA_FILE_IO_MMAP::ECA_FILE_IO_MMAP(void) { }
 ECA_FILE_IO_MMAP::~ECA_FILE_IO_MMAP(void) { }
 
-void ECA_FILE_IO_MMAP::open_file(const string& fname, 
-				 const string& fmode)
+void ECA_FILE_IO_MMAP::open_file(const std::string& fname, 
+				 const std::string& fmode)
 {
+#ifdef HAVE_MMAP
   int openflags = O_RDWR;
   int mmapflags = PROT_READ | PROT_WRITE;
   fname_rep = fname;
@@ -73,6 +78,10 @@ void ECA_FILE_IO_MMAP::open_file(const string& fname,
       mode_rep = "";
     }
   }
+#else /* HAVE_MMAP */
+  file_ready_rep = false;
+  mode_rep = "";
+#endif
 }
 
 void ECA_FILE_IO_MMAP::close_file(void) {
@@ -81,7 +90,7 @@ void ECA_FILE_IO_MMAP::close_file(void) {
   ::close(fd_rep);
 }
 
-void ECA_FILE_IO_MMAP::read_to_buffer(void* obuf, long int bytes) {
+void ECA_FILE_IO_MMAP::read_to_buffer(void* obuf, off_t bytes) {
   if (is_file_ready() == false) {
     bytes_rep = 0;
     file_ended_rep = true;
@@ -92,14 +101,13 @@ void ECA_FILE_IO_MMAP::read_to_buffer(void* obuf, long int bytes) {
     bytes = flength_rep - fposition_rep;
 
 //    cerr << fname_rep << ": mmap read " << fposition_rep << " -> ";
-  ::memcpy(obuf, buffer_repp + fposition_rep, bytes);
+  std::memcpy(obuf, buffer_repp + fposition_rep, bytes);
 //    cerr <<  fposition_rep + bytes << "." << endl;
   set_file_position(fposition_rep + bytes, false);
   bytes_rep = bytes;
 }
 
-void ECA_FILE_IO_MMAP::write_from_buffer(void* obuf, long int
-				   bytes) { 
+void ECA_FILE_IO_MMAP::write_from_buffer(void* obuf, off_t bytes) { 
   if (is_file_ready() == false) {
     bytes_rep = 0;
     file_ended_rep = true;
@@ -109,17 +117,17 @@ void ECA_FILE_IO_MMAP::write_from_buffer(void* obuf, long int
   if (fposition_rep + bytes > flength_rep)
     bytes = flength_rep - fposition_rep;
 
-  ::memcpy(buffer_repp + fposition_rep, obuf, bytes);
+  std::memcpy(buffer_repp + fposition_rep, obuf, bytes);
   set_file_position(fposition_rep + bytes, false);
   bytes_rep = bytes;
 }
 
-long int ECA_FILE_IO_MMAP::file_bytes_processed(void) const { return(bytes_rep); }
+off_t ECA_FILE_IO_MMAP::file_bytes_processed(void) const { return(bytes_rep); }
 bool ECA_FILE_IO_MMAP::is_file_ready(void) const { return(file_ready_rep); }
 bool ECA_FILE_IO_MMAP::is_file_ended(void) const { return(file_ended_rep); }
 bool ECA_FILE_IO_MMAP::is_file_error(void) const { return(!file_ready_rep && !file_ended_rep); }
 
-void ECA_FILE_IO_MMAP::set_file_position(long int newpos, bool seek) { 
+void ECA_FILE_IO_MMAP::set_file_position(off_t newpos, bool seek) { 
   fposition_rep = newpos;
   if (fposition_rep >= flength_rep) {
     fposition_rep = flength_rep;
@@ -132,7 +140,7 @@ void ECA_FILE_IO_MMAP::set_file_position(long int newpos, bool seek) {
   }
 }
 
-void ECA_FILE_IO_MMAP::set_file_position_advance(long int fw) { 
+void ECA_FILE_IO_MMAP::set_file_position_advance(off_t fw) { 
   set_file_position(fposition_rep + fw, false);
 }
 
@@ -140,10 +148,10 @@ void ECA_FILE_IO_MMAP::set_file_position_end(void) {
   fposition_rep = get_file_length();
 }
 
-long int ECA_FILE_IO_MMAP::get_file_position(void) const { return(fposition_rep); }
+off_t ECA_FILE_IO_MMAP::get_file_position(void) const { return(fposition_rep); }
 
-long int ECA_FILE_IO_MMAP::get_file_length(void) const {
+off_t ECA_FILE_IO_MMAP::get_file_length(void) const {
   struct stat stattemp;
   fstat(fd_rep, &stattemp);
-  return((long int)stattemp.st_size);
+  return((off_t)stattemp.st_size);
 }
