@@ -3,12 +3,7 @@
 
 #include <string>
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-#ifdef USE_CXX_STD_NAMESPACE
 using std::string;
-#endif
 
 /**
  * Virtual class for ecasound objects
@@ -19,20 +14,20 @@ class ECA_OBJECT {
 
  public:
 
+  virtual ~ECA_OBJECT (void) { }
+
   /**
    * Object name used to identify the object type. In most 
    * cases, object name is same for all class instances.
    * Must be implemented in all subclasses.
    */
-  virtual string name(void) const = 0;
+  virtual std::string name(void) const = 0;
 
   /**
    * Object description. Description should be short, informative
    * and unformatted.
    */
-  virtual string description(void) const { return(name()); }
-
-  virtual ~ECA_OBJECT (void) { }
+  virtual std::string description(void) const { return(name()); }
 };
 
 #endif
