@@ -8,33 +8,32 @@
  * Various simple functions that operate on sample buffer data. This 
  * class really is just an extension of class SAMPLE_BUFFER.
  */
-template<class T>
-class SAMPLE_BUFFER_FUNCTIONS_BASE {
+class SAMPLE_BUFFER_FUNCTIONS {
 
  public:
 
-  typedef SAMPLE_BUFFER_BASE<T>::sample_type sample_type;
+  typedef SAMPLE_BUFFER::sample_t sample_t;
 
-  static sample_type max_value(const SAMPLE_BUFFER_BASE<T>& buf, 
+  static sample_t max_value(const SAMPLE_BUFFER& buf, 
 			       SAMPLE_BUFFER::channel_size_t channel) {
-    sample_type t = SAMPLE_SPECS::impl_min_value;
+    sample_t t = SAMPLE_SPECS::impl_min_value;
     for(SAMPLE_BUFFER::buf_size_t m = 0; m < buf.buffersize_rep; m++) {
       if (buf.buffer[channel][m] > t) t = buf.buffer[channel][m];
     }
     return(t);
   }
 
-  static sample_type min_value(const SAMPLE_BUFFER_BASE<T>& buf, 
+  static sample_t min_value(const SAMPLE_BUFFER& buf, 
 			SAMPLE_BUFFER::channel_size_t channel) {
-    sample_type t = SAMPLE_SPECS::impl_max_value;
+    sample_t t = SAMPLE_SPECS::impl_max_value;
     for(SAMPLE_BUFFER::buf_size_t m = 0; m < buf.buffersize_rep; m++) {
       if (buf.buffer[channel][m] < t) t = buf.buffer[channel][m];
     }
     return(t);
   }
 
-  static sample_type average_amplitude(const SAMPLE_BUFFER_BASE<T>& buf) {
-    sample_type temp_avg = 0.0;
+  static sample_t average_amplitude(const SAMPLE_BUFFER& buf) {
+    sample_t temp_avg = 0.0;
     for(int n = 0; n < buf.channel_count_rep; n++) {
       for(SAMPLE_BUFFER::buf_size_t m = 0; m < buf.buffersize_rep; m++) {
 	temp_avg += fabs(buf.buffer[n][m] - SAMPLE_SPECS::silent_value);
@@ -43,8 +42,8 @@ class SAMPLE_BUFFER_FUNCTIONS_BASE {
     return(temp_avg / buf.channel_count_rep / buf.buffersize_rep);
   }
 
-  static sample_type RMS_volume(const SAMPLE_BUFFER_BASE<T>& buf) {
-    sample_type temp_avg = 0.0;
+  static sample_t RMS_volume(const SAMPLE_BUFFER& buf) {
+    sample_t temp_avg = 0.0;
     for(int n = 0; n < buf.channel_count_rep; n++) {
       for(SAMPLE_BUFFER::buf_size_t m = 0; m < buf.buffersize_rep; m++) {
 	temp_avg += buf.buffer[n][m] * buf.buffer[n][m];
@@ -53,10 +52,10 @@ class SAMPLE_BUFFER_FUNCTIONS_BASE {
     return(sqrt(temp_avg / buf.channel_count_rep / buf.buffersize_rep));
   }
 
-  static sample_type average_amplitude(const SAMPLE_BUFFER_BASE<T>& buf,
-				SAMPLE_BUFFER::channel_size_t channel,
-				SAMPLE_BUFFER::buf_size_t count_samples) {
-      sample_type temp_avg = 0.0;
+  static sample_t average_amplitude(const SAMPLE_BUFFER& buf,
+				       SAMPLE_BUFFER::channel_size_t channel,
+				       SAMPLE_BUFFER::buf_size_t count_samples) {
+      sample_t temp_avg = 0.0;
       if (count_samples == 0) count_samples = static_cast<int>(buf.channel_count_rep);
       
       for(SAMPLE_BUFFER::buf_size_t n = 0; n < buf.buffersize_rep; n++) {
@@ -66,10 +65,10 @@ class SAMPLE_BUFFER_FUNCTIONS_BASE {
       return(temp_avg / count_samples);
   }
   
-  static sample_type RMS_volume(const SAMPLE_BUFFER_BASE<T>& buf,
+  static sample_t RMS_volume(const SAMPLE_BUFFER& buf,
 				SAMPLE_BUFFER::channel_size_t channel,
 				SAMPLE_BUFFER::buf_size_t count_samples) {
-    sample_type temp_avg = 0.0;
+    sample_t temp_avg = 0.0;
     if (count_samples == 0) count_samples = static_cast<int>(buf.channel_count_rep);
     for(SAMPLE_BUFFER::buf_size_t n = 0; n < buf.buffersize_rep; n++) {
       temp_avg += buf.buffer[channel][n] * buf.buffer[channel][n];
@@ -78,6 +77,4 @@ class SAMPLE_BUFFER_FUNCTIONS_BASE {
   }
 };
 
-typedef SAMPLE_BUFFER_FUNCTIONS_BASE<SAMPLE_BUFFER::sample_type> SAMPLE_BUFFER_FUNCTIONS;
-
 #endif
