@@ -1,10 +1,13 @@
-#ifndef _SAMPLEBUFFER_ITERATORS_H
-#define _SAMPLEBUFFER_ITERATORS_H
+#ifndef INCLUDED_SAMPLEBUFFER_ITERATORS_H
+#define INCLUDED_SAMPLEBUFFER_ITERATORS_H
 
 #include "samplebuffer.h"
 
 /**
  * Iterate through all samples. No specific order.
+ *
+ * Related design patterns:
+ *     - Iterator (GoF257)
  */
 class SAMPLE_ITERATOR {
 
@@ -39,7 +42,7 @@ class SAMPLE_ITERATOR {
   /**
    * Returns a pointer to the current sample.
    */
-  inline SAMPLE_SPECS::sample_type* current(void) { return(&(target->buffer[channel_index][index])); }
+  inline SAMPLE_SPECS::sample_t* current(void) { return(&(target->buffer[channel_index][index])); }
 };
 
 /**
@@ -47,6 +50,9 @@ class SAMPLE_ITERATOR {
  *
  * Notice! This iterator can be used to add extra
  * channels to the sample data.
+ *
+ * Related design patterns:
+ *     - Iterator (GoF257)
  */
 class SAMPLE_ITERATOR_CHANNEL {
 
@@ -84,11 +90,14 @@ class SAMPLE_ITERATOR_CHANNEL {
   /**
    * Returns a pointer to the current sample.
    */
-  inline SAMPLE_SPECS::sample_type* current(void) { return(&target->buffer[channel_index][index]); }
+  inline SAMPLE_SPECS::sample_t* current(void) { return(&target->buffer[channel_index][index]); }
 };
 
 /**
  * Iterate through all samples, one channel at a time.
+ *
+ * Related design patterns:
+ *     - Iterator (GoF257)
  */
 class SAMPLE_ITERATOR_CHANNELS {
 
@@ -123,7 +132,7 @@ class SAMPLE_ITERATOR_CHANNELS {
   /**
    * Returns a pointer to the current sample.
    */
-  inline SAMPLE_SPECS::sample_type* current(void) { return(&(target->buffer[channel_index][index])); }
+  inline SAMPLE_SPECS::sample_t* current(void) { return(&(target->buffer[channel_index][index])); }
 
   /**
    * Returns current channel index (starting from 0)
@@ -133,6 +142,9 @@ class SAMPLE_ITERATOR_CHANNELS {
 
 /**
  * Iterate through all samples, one sample frame (interleaved) at a time.
+ *
+ * Related design patterns:
+ *     - Iterator (GoF257)
  */
 class SAMPLE_ITERATOR_INTERLEAVED {
 
@@ -166,7 +178,7 @@ class SAMPLE_ITERATOR_INTERLEAVED {
   /**
    * Returns a pointer to the current sample.
    */
-  inline SAMPLE_SPECS::sample_type* current(int channel) { return(&target->buffer[channel][index]); }
+  inline SAMPLE_SPECS::sample_t* current(int channel) { return(&target->buffer[channel][index]); }
 };
 
 #endif
